/**
 * 项目：中核预埋件检测
 * @Author: xiongwei
 * @Date: 2024-11-15 11:50:00
 */

import { defHttp } from '@/utils/http/axios';
import {
  TaskProgress,
  TaskProgressParams,
  TaskProgressPageResult,
} from '../model/taskProgress';

const baseApi = '/v1/data/task-progress';

/**
 * 新增
 */
export const add = (entity: TaskProgress) =>
  defHttp.post<TaskProgress>({ url: `${baseApi}/`, data: entity });

/**
 * 更新
 */
export const update = (entity: TaskProgress, updateAllFields = false) =>
  defHttp.put<TaskProgress>({ url: `${baseApi}/`, data: entity, params: { updateAllFields } });

/**
 * 删除
 */
export const remove = (id: any) =>
  defHttp.delete<number>({ url: `${baseApi}/${id}` });

/**
 * 分页查询
 */
export const search = (params?: TaskProgressParams) =>
  defHttp.get<TaskProgressPageResult>({ url: `${baseApi}/search`, params });

/**
 * 列表查询
 */
export const all = (params?: TaskProgressParams) =>
  defHttp.get<TaskProgress[]>({ url: `${baseApi}/all`, params });

/**
 * 通过主键查询
 */
export const getById = (id: any) =>
  defHttp.get<TaskProgress>({ url: `${baseApi}/${id}` });

/**
 * 单个查询
 */
export const getOne = (params?: TaskProgressParams) =>
  defHttp.get<TaskProgress>({ url: `${baseApi}/one`, params });

/**
 * 批量删除
 */
export const batchRemove = (idList: Array<any>) =>
  defHttp.post<boolean>({ url: `${baseApi}/batch-delete`, data: idList });

/**
 * 批量新增
 */
export const batchAdd = (entityList: Array<TaskProgress>) =>
  defHttp.post<boolean>({ url: `${baseApi}/batch-save`, data: entityList });

/**
 * 批量更新
 */
export const batchUpdate = (entityList: Array<TaskProgress>) =>
  defHttp.post<boolean>({ url: `${baseApi}/batch-update`, data: entityList });

/**
 * 查询数量
 */
export const count = (params?: TaskProgressParams) =>
  defHttp.get<number>({ url: `${baseApi}/count`, params });


